@@ -1,17 +1,16 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
-from pmb.core.context import get_context
-from pmb.core.arch import Arch
-from pmb.helpers import logging
-from pmb.types import Bootimg
-from pathlib import Path
 import os
+from pathlib import Path
+
 import pmb.helpers.cli
 import pmb.helpers.devices
 import pmb.helpers.run
-import pmb.aportgen.core
-import pmb.parse.apkindex
 import pmb.parse
+from pmb.core.arch import Arch
+from pmb.core.context import get_context
+from pmb.helpers import logging
+from pmb.types import Bootimg
 
 
 def ask_for_architecture() -> Arch:
@@ -26,10 +25,8 @@ def ask_for_architecture() -> Arch:
         if ret in architectures:
             return Arch.from_str(ret)
         logging.fatal(
-            "ERROR: Invalid architecture specified. If you want to"
-            " add a new architecture, edit"
-            " build_device_architectures in"
-            " pmb/config/__init__.py."
+            "ERROR: Invalid architecture specified. If you want to add a new architecture, edit "
+            "build_device_architectures in pmb/config/__init__.py."
         )
 
 
@@ -59,8 +56,9 @@ def ask_for_chassis() -> str:
 
     logging.info("What type of device is it?")
     logging.info("Valid types are: " + ", ".join(types))
+    logging.info("Leave empty if this property is defined elsewhere, e.g. in Devicetree or ACPI")
     return pmb.helpers.cli.ask(
-        "Chassis", None, None, True, validation_regex="|".join(types), complete=types
+        "Chassis", None, None, True, validation_regex="|".join([*types, "None"]), complete=types
     )
 
 
@@ -83,9 +81,7 @@ def ask_for_flash_method() -> str:
                 while True:
                     logging.info('Does the device use the "isolated recovery" or boot.img?')
                     logging.info(
-                        "<https://wiki.postmarketos.org/wiki"
-                        "/Deviceinfo_flash_methods#Isorec_or_bootimg"
-                        ".3F>"
+                        "<https://wiki.postmarketos.org/wiki/Deviceinfo_flash_methods#Isorec_or_bootimg.3F>"
                     )
                     heimdall_type = pmb.helpers.cli.ask("Type", heimdall_types, heimdall_types[0])
                     if heimdall_type in heimdall_types:
@@ -95,19 +91,16 @@ def ask_for_flash_method() -> str:
             return method
 
         logging.fatal(
-            "ERROR: Invalid flash method specified. If you want to"
-            " add a new flash method, edit flash_methods in"
-            " pmb/config/__init__.py."
+            "ERROR: Invalid flash method specified. If you want to add a new flash method, edit "
+            "flash_methods in pmb/config/__init__.py."
         )
 
 
 def ask_for_bootimg() -> Bootimg | None:
     logging.info(
-        "You can analyze a known working boot.img file to"
-        " automatically fill out the flasher information for your"
-        " deviceinfo file. Either specify the path to an image or"
-        " press return to skip this step (you can do it later with"
-        " 'pmbootstrap bootimg_analyze')."
+        "You can analyze a known working boot.img file to automatically fill out the flasher "
+        "information for your deviceinfo file. Either specify the path to an image or press return "
+        "to skip this step (you can do it later with 'pmbootstrap bootimg_analyze')."
     )
 
     while True:
@@ -210,7 +203,11 @@ def generate_deviceinfo(
         deviceinfo_arch="{arch}"
 
         # Device related
-        deviceinfo_chassis="{chassis}"
+        """
+
+    content += f'deviceinfo_chassis="{chassis}"\n' if chassis != "None" else ""
+
+    content += f"""\
         deviceinfo_external_storage="{external_storage}"
 
         # Bootloader related
@@ -287,7 +284,7 @@ def generate_apkbuild(
     # Dependencies
     depends = ["postmarketos-base"]
     if device_category == pmb.helpers.devices.DeviceCategory.DOWNSTREAM:
-        depends += ["linux-" + "-".join(pkgname.split("-")[1:])]
+        depends += ["linux-" + "-".join(pkgname.split("-")[1:]), "postmarketos-base-downstream"]
     else:
         depends += ["linux-CHANGEME"]
 
@@ -301,6 +298,7 @@ def generate_apkbuild(
     depends_fmt = ("\n" + " " * 12).join(depends)
     content = f"""\
         # Reference: <https://postmarketos.org/devicepkg>
+        maintainer=""
         pkgname={pkgname}
         pkgdesc="{name}"
         pkgver=1
