@@ -1,25 +1,23 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import os
+
+import pmb.chroot.apk
+import pmb.helpers.other
+import pmb.helpers.run
+import pmb.parse
 from pmb.core.arch import Arch
 from pmb.core.chroot import Chroot
 from pmb.helpers import logging
 
-import pmb.helpers.run
-import pmb.helpers.other
-import pmb.parse
-import pmb.chroot.apk
-
 
 def is_registered(arch_qemu: str | Arch) -> bool:
     return os.path.exists(f"/proc/sys/fs/binfmt_misc/qemu-{arch_qemu}")
 
 
 def register(arch: Arch) -> None:
-    """
-    Get arch, magic, mask.
-    """
-    arch_qemu = arch.qemu()
+    """Get arch, magic, mask."""
+    arch_qemu = arch.qemu_user()
     chroot = Chroot.native()
 
     # always make sure the qemu-<arch> binary is installed, since registering
@@ -58,7 +56,7 @@ def register(arch: Arch) -> None:
 
 
 def unregister(arch: Arch) -> None:
-    arch_qemu = arch.qemu()
+    arch_qemu = arch.qemu_user()
     binfmt_file = "/proc/sys/fs/binfmt_misc/qemu-" + arch_qemu
     if not os.path.exists(binfmt_file):
         return
