@@ -2,20 +2,21 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import annotations
-from pmb.types import PmbArgs
-from pmb.helpers import frontend
 
-from .base import Command
+from pmb.helpers import frontend
+from pmb.types import PmbArgs
+
 from .aportgen import Aportgen
+from .base import Command
 from .flasher import Flasher
-from .log import Log
 from .index import Index
-from .shutdown import Shutdown
-from .test import Test
+from .kconfig import KConfigCheck, KConfigEdit, KConfigGenerate, KConfigMigrate
+from .log import Log
 from .pkgrel_bump import PkgrelBump
 from .pkgver_bump import PkgverBump
 from .pull import Pull
-from .kconfig import KConfigCheck, KConfigEdit, KConfigMigrate
+from .shutdown import Shutdown
+from .test import Test
 
 """New way to model pmbootstrap subcommands that can be invoked without PmbArgs."""
 
@@ -89,13 +90,23 @@ def run_command(args: PmbArgs) -> None:
         case "kconfig":
             match args.action_kconfig:
                 case "check":
+                    categories = args.categories.split(",") if args.categories else []
                     command = KConfigCheck(
-                        args.kconfig_check_details, args.file, args.package, args.keep_going
+                        args.kconfig_check_details,
+                        args.file,
+                        args.package,
+                        args.keep_going,
+                        categories,
                     )
                 case "edit":
-                    command = KConfigEdit(args.package[0], args.arch, args.xconfig, args.nconfig)
+                    command = KConfigEdit(
+                        args.package[0], args.arch, args.xconfig, args.nconfig, args.fragment
+                    )
                 case "migrate":
                     command = KConfigMigrate(args.package, args.arch)
+                case "generate":
+                    command = KConfigGenerate(args.package, args.arch)
+
         case _:
             raise NotImplementedError(f"Command '{args.action}' is not implemented.")
 
