@@ -3,10 +3,12 @@
 
 from __future__ import annotations
 
-import pmb.helpers.git
-import pmb.config
-import pmb.parse.kconfig
 import logging
+from pathlib import Path
+
+import pmb.config
+import pmb.helpers.git
+import pmb.parse.kconfig
 from pmb import commands
 from pmb.build.kconfig import KConfigUI
 from pmb.core.arch import Arch
@@ -16,21 +18,25 @@ from pmb.helpers.exceptions import NonBugError
 
 class KConfigCheck(commands.Command):
     def __init__(
-        self, details: bool, file: str, pkgname: str | list[str], keep_going: bool
+        self,
+        details: bool,
+        file: str | None,
+        pkgname: str | list[str],
+        keep_going: bool,
+        categories: list[str],
     ) -> None:
         self.details = details
-        self.file = file
+        self.file = Path(file) if file is not None else None
         self.pkgname_list = [pkgname] if isinstance(pkgname, str) else pkgname
         self.keep_going = keep_going
+        self.categories = categories
 
     def run(self) -> None:
-        # Build the components list from cli arguments (--waydroid etc.)
-        components_list: list[str] = []
         error_msg = "kconfig check failed! More info: https://postmarketos.org/kconfig"
 
         # Handle passing a file directly
         if self.file:
-            if pmb.parse.kconfig.check_file(self.file, components_list, details=self.details):
+            if pmb.parse.kconfig.check_file(self.file, self.categories, details=self.details):
                 logging.info("kconfig check succeeded!")
                 return
             raise NonBugError(error_msg)
@@ -53,7 +59,7 @@ class KConfigCheck(commands.Command):
                 if "!pmb:kconfigcheck" in apkbuild["options"]:
                     skipped += 1
                     continue
-            if not pmb.parse.kconfig.check(package, components_list, details=self.details):
+            if not pmb.parse.kconfig.check(package, self.categories, details=self.details):
                 error = True
                 if not self.keep_going:
                     break
@@ -72,10 +78,16 @@ class KConfigCheck(commands.Command):
 
 class KConfigEdit(commands.Command):
     def __init__(
-        self, pkgname: str, arch: Arch | None, use_xconfig: bool, use_nconfig: bool
+        self,
+        pkgname: str,
+        arch: Arch | None,
+        use_xconfig: bool,
+        use_nconfig: bool,
+        fragment: str | None = None,
     ) -> None:
         self.pkgname = pkgname
         self.arch = arch
+        self.fragment = fragment
 
         if use_xconfig and use_nconfig:
             raise AssertionError
@@ -88,7 +100,7 @@ class KConfigEdit(commands.Command):
             self.chosen_ui = KConfigUI.MENUCONFIG
 
     def run(self) -> None:
-        pmb.build.kconfig.edit_config(self.pkgname, self.arch, self.chosen_ui)
+        pmb.build.kconfig.edit_config(self.pkgname, self.arch, self.chosen_ui, self.fragment)
 
 
 class KConfigMigrate(commands.Command):
@@ -99,3 +111,13 @@ class KConfigMigrate(commands.Command):
     def run(self) -> None:
         for pkgname in self.pkgname_list:
             pmb.build.kconfig.migrate_config(pkgname, self.arch)
+
+
+class KConfigGenerate(commands.Command):
+    def __init__(self, pkgname: str | list[str], arch: Arch | None) -> None:
+        self.pkgname_list = [pkgname] if isinstance(pkgname, str) else pkgname
+        self.arch = arch
+
+    def run(self) -> None:
+        for pkgname in self.pkgname_list:
+            pmb.build.kconfig.generate_config(pkgname, self.arch)
