@@ -2,22 +2,23 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import annotations
-from pmb import commands
-from pmb.types import PathString
-from pmb.helpers import run
-from pmb.core.context import get_context
+
 import pmb.config
+from pmb import commands
+from pmb.core.context import get_context
+from pmb.helpers import run
+from pmb.types import PathString, RunOutputTypeDefault
 
 
 class Log(commands.Command):
     clear_log: bool
     lines: int
 
-    def __init__(self, clear_log: bool, lines: int):
+    def __init__(self, clear_log: bool, lines: int) -> None:
         self.clear_log = clear_log
         self.lines = lines
 
-    def run(self):
+    def run(self) -> None:
         context = get_context()
         log_testsuite = pmb.config.pmb_src / ".pytest_tmp/log_testsuite.txt"
 
@@ -38,4 +39,4 @@ class Log(commands.Command):
         # looks for an error / what's currently going on).
         cmd += [context.log]
 
-        run.user(cmd, output="tui")
+        run.user(cmd, output=RunOutputTypeDefault.TUI)
