@@ -2,13 +2,14 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import annotations
-from pmb import commands
+
 import pmb.chroot
+from pmb import commands
 
 
 class Shutdown(commands.Command):
-    def __init__(self):
+    def __init__(self) -> None:
         pass
 
-    def run(self):
+    def run(self) -> None:
         pmb.chroot.shutdown()
