@@ -1,28 +1,20 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
-from pmb.core.context import get_context
-from pmb.core.chroot import Chroot
-from pmb.core.config import SystemdConfig
-from pmb.core.context import Context
-from pmb.core.pkgrepo import pkgrepo_default_path
-from pmb.helpers import logging
-from pmb.helpers.exceptions import NonBugError
 import contextlib
 import glob
 import heapq
 import json
 import os
 import shutil
+import subprocess
 import urllib
 from pathlib import Path
 from typing import Any
 
 import pmb.aportgen
+import pmb.chroot.zap
 import pmb.config
 import pmb.config.pmaports
-from pmb.config.pmaports import DEVELOPMENT_CHANNEL
-from pmb.core import Config
-from pmb.types import Apkbuild, PmbArgs
 import pmb.helpers.cli
 import pmb.helpers.devices
 import pmb.helpers.git
@@ -30,11 +22,18 @@ import pmb.helpers.http
 import pmb.helpers.other
 import pmb.helpers.pmaports
 import pmb.helpers.ui
-import pmb.chroot.zap
-import pmb.parse.deviceinfo
-from pmb.parse.deviceinfo import Deviceinfo
 import pmb.parse._apkbuild
-import subprocess
+import pmb.parse.deviceinfo
+from pmb.config.pmaports import DEVELOPMENT_CHANNEL
+from pmb.core import Config
+from pmb.core.chroot import Chroot
+from pmb.core.config import SystemdConfig
+from pmb.core.context import Context, get_context
+from pmb.core.pkgrepo import pkgrepo_default_path
+from pmb.helpers import logging
+from pmb.helpers.exceptions import NonBugError
+from pmb.parse.deviceinfo import Deviceinfo
+from pmb.types import Apkbuild, PmbArgs
 
 
 def require_programs() -> None:
@@ -83,7 +82,8 @@ def require_programs() -> None:
 
 
 def ask_for_username(default_user: str) -> str:
-    """Ask for a reasonable username for the non-root user.
+    """
+    Ask for a reasonable username for the non-root user.
 
     :returns: the username
     """
@@ -100,7 +100,8 @@ def ask_for_username(default_user: str) -> str:
 
 
 def ask_for_work_path(default: Path | None) -> tuple[Path, bool]:
-    """Ask for the work path, until we can create it (when it does not exist) and write into it.
+    """
+    Ask for the work path, until we can create it (when it does not exist) and write into it.
 
     :returns: (path, exists)
         * path: is the full path, with expanded ~ sign
@@ -113,39 +114,39 @@ def ask_for_work_path(default: Path | None) -> tuple[Path, bool]:
     )
     while True:
         try:
-            work = os.path.expanduser(
-                pmb.helpers.cli.ask(
-                    "Work path", None, str(default) if default is not None else default, False
+            work = (
+                Path(
+                    pmb.helpers.cli.ask(
+                        "Work path", None, str(default) if default is not None else default, False
+                    )
                 )
+                .expanduser()
+                .resolve()
             )
-            work = os.path.realpath(work)
-            exists = os.path.exists(work)
+            exists = work.exists()
 
             # Work must not be inside the pmbootstrap path
-            if work == pmb.config.pmb_src or work.startswith(f"{pmb.config.pmb_src}/"):
+            if work == pmb.config.pmb_src or str(work).startswith(f"{pmb.config.pmb_src}/"):
                 logging.fatal(
-                    "ERROR: The work path must not be inside the"
-                    " pmbootstrap path. Please specify another"
-                    " location."
+                    "ERROR: The work path must not be inside the pmbootstrap"
+                    " path. Please specify another location."
                 )
                 continue
 
             # Create the folder with a version file
-            if not exists:
-                os.makedirs(work, 0o700, True)
+            work.mkdir(mode=0o700, parents=True, exist_ok=True)
 
             # If the version file doesn't exists yet because we either just
             # created the work directory or the user has deleted it for
             # whatever reason then we need to write initialize it.
-            work_version_file = f"{work}/version"
+            work_version_file = work / "version"
             if not os.path.isfile(work_version_file):
-                with open(work_version_file, "w") as handle:
-                    handle.write(f"{pmb.config.work_version}\n")
+                work_version_file.write_text(f"{pmb.config.work_version}\n")
 
             # Create cache_git dir, so it is owned by the host system's user
             # (otherwise pmb.helpers.mount.bind would create it as root)
-            os.makedirs(f"{work}/cache_git", 0o700, True)
-            return (Path(work), exists)
+            work.joinpath("cache_git").mkdir(mode=0o700, parents=True, exist_ok=True)
+            return (work, exists)
         except OSError:
             logging.fatal(
                 "ERROR: Could not create this folder, or write inside it! Please try again."
@@ -153,7 +154,8 @@ def ask_for_work_path(default: Path | None) -> tuple[Path, bool]:
 
 
 def ask_for_pmaports_path(default: Path) -> Path:
-    """Ask for a path for pmaports, until it can either be created or already exists.
+    """
+    Ask for a path for pmaports, until it can either be created or already exists.
 
     :returns: full path to the directory, with a leading ~ expanded.
     """
@@ -192,7 +194,8 @@ def ask_for_pmaports_path(default: Path) -> Path:
 
 
 def ask_for_channel(config: Config) -> str:
-    """Ask for the postmarketOS release channel.
+    """
+    Ask for the postmarketOS release channel.
     The channel dictates, which pmaports branch pmbootstrap will check out,
     and which repository URLs will be used when initializing chroots.
 
@@ -230,7 +233,7 @@ def ask_for_channel(config: Config) -> str:
 def ask_for_ui(deviceinfo: Deviceinfo) -> str:
     ui_list = pmb.helpers.ui.list_ui(deviceinfo.arch)
     hidden_ui_count = 0
-    if deviceinfo.drm != "true":
+    if not deviceinfo.drm:
         for i in reversed(range(len(ui_list))):
             pkgname = f"postmarketos-ui-{ui_list[i][0]}"
             apkbuild = pmb.helpers.pmaports.get(pkgname, subpackages=False, must_exist=False)
@@ -348,7 +351,8 @@ def ask_for_timezone() -> str:
 
 
 def ask_for_provider_select(apkbuild: dict[str, Any], providers_cfg: dict[str, str]) -> None:
-    """Ask for selectable providers that are specified using "_pmb_select" in a APKBUILD.
+    """
+    Ask for selectable providers that are specified using "_pmb_select" in a APKBUILD.
 
     :param apkbuild: the APKBUILD with the _pmb_select
     :param providers_cfg: the configuration section with previously selected
@@ -412,7 +416,8 @@ def ask_for_provider_select(apkbuild: dict[str, Any], providers_cfg: dict[str, s
 
 
 def ask_for_provider_select_pkg(pkgname: str, providers_cfg: dict[str, str]) -> None:
-    """Look up the APKBUILD for the specified pkgname and ask for selectable
+    """
+    Look up the APKBUILD for the specified pkgname and ask for selectable
     providers that are specified using "_pmb_select".
 
     :param pkgname: name of the package to search APKBUILD for
@@ -427,7 +432,8 @@ def ask_for_provider_select_pkg(pkgname: str, providers_cfg: dict[str, str]) ->
 
 
 def ask_for_device_kernel(config: Config, device: str) -> str:
-    """Ask for the kernel that should be used with the device.
+    """
+    Ask for the kernel that should be used with the device.
 
     :param device: code name, e.g. "lg-mako"
 
@@ -496,8 +502,10 @@ def ask_for_mainline_downstream() -> pmb.helpers.devices.DeviceCategory:
 
 
 def switch_channel(config: Config, channel: str) -> None:
-    """Wrapper around `pmb.config.pmaports.switch_to_channel_branch(channel)` that also handles
-    installing git hooks if master is selected."""
+    """
+    Wrapper around `pmb.config.pmaports.switch_to_channel_branch(channel)` that also handles
+    installing git hooks if master is selected.
+    """
     pmb.config.pmaports.switch_to_channel_branch(channel)
     # FIXME: ???
     config.is_default_channel = False
@@ -520,7 +528,6 @@ def ask_for_device(context: Context, channel: str) -> tuple[str, bool, str]:
         * device_exists: bool indicating if device port exists in repo
         * kernel: type of kernel (downstream, etc)
     """
-
     styles = pmb.config.styles
 
     def new_port_message(has_codename: bool = True) -> str:
@@ -720,11 +727,9 @@ def ask_for_additional_options(config: Config) -> None:
 def ask_for_mirror() -> str:
     regex = "^(?:[1-9][0-9]*|best)$"  # single non-zero number only
 
-    json_path = pmb.helpers.http.download(
+    s = pmb.helpers.http.download(
         "https://postmarketos.org/mirrors.json", "pmos_mirrors", cache=False
-    )
-    with open(json_path) as handle:
-        s = handle.read()
+    ).read_text()
 
     logging.info("list of available mirrors:")
     mirrors = json.loads(s)
@@ -1017,7 +1022,7 @@ def frontend(args: PmbArgs) -> None:
         and len(list(Chroot.iter_patterns()))
         and pmb.helpers.cli.confirm("Zap existing chroots to apply configuration?", default=True)
     ):
-        setattr(args, "deviceinfo", deviceinfo)
+        args.deviceinfo = deviceinfo
 
         # Do not zap any existing packages or cache_http directories
         pmb.chroot.zap(confirm=False)
