@@ -6,7 +6,7 @@
 from dataclasses import dataclass
 from enum import Enum
 from pathlib import Path
-from typing import overload, Literal
+from typing import Literal, overload
 
 from .config import Config
 
