@@ -1,23 +1,22 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import os
-from pmb.core.arch import Arch
-from pmb.helpers import logging
 import shutil
+import stat
 import tarfile
 import tempfile
-import stat
 from pathlib import Path
 
-import pmb.helpers.apk
-import pmb.helpers.run
-import pmb.helpers.repo
 import pmb.config
-import pmb.config.file
-import pmb.parse.apkindex
+import pmb.helpers.apk
 import pmb.helpers.http
-import pmb.parse.version
+import pmb.helpers.repo
+import pmb.helpers.run
+import pmb.parse.apkindex
+from pmb.core.arch import Arch
 from pmb.core.context import get_context
+from pmb.helpers import logging
+from pmb.helpers.exceptions import NonBugError
 
 
 def read_signature_info(tar: tarfile.TarFile) -> tuple[str, str]:
@@ -56,9 +55,7 @@ def read_signature_info(tar: tarfile.TarFile) -> tuple[str, str]:
 
 
 def extract_temp(tar: tarfile.TarFile, sigfilename: str) -> dict[str, dict]:
-    """
-    Extract apk.static and signature as temporary files.
-    """
+    """Extract apk.static and signature as temporary files."""
     ret = {
         "apk": {"filename": "sbin/apk.static", "temp_path": None},
         "sig": {"filename": sigfilename, "temp_path": None},
@@ -102,7 +99,7 @@ def verify_signature(files: dict[str, dict], sigkey_path: str) -> None:
                 files["apk"]["temp_path"],
             ]
         )
-    except BaseException:
+    except BaseException as exception:
         os.unlink(files["sig"]["temp_path"])
         os.unlink(files["apk"]["temp_path"])
         raise RuntimeError(
@@ -110,7 +107,7 @@ def verify_signature(files: dict[str, dict], sigkey_path: str) -> None:
             " Either openssl is not installed, or the"
             " download failed. Run 'pmbootstrap zap -hc' to"
             " delete the download and try again."
-        )
+        ) from exception
 
 
 def extract(version: str, apk_path: Path) -> None:
@@ -152,9 +149,7 @@ def extract(version: str, apk_path: Path) -> None:
 
 
 def download(file: str) -> Path:
-    """
-    Download a single file from an Alpine mirror.
-    """
+    """Download a single file from an Alpine mirror."""
     channel_cfg = pmb.config.pmaports.read_config_channel()
     mirrordir = channel_cfg["mirrordir_alpine"]
     base_url = f"{get_context().config.mirrors['alpine']}{mirrordir}/main/{Arch.native()}"
@@ -162,9 +157,7 @@ def download(file: str) -> Path:
 
 
 def init() -> None:
-    """
-    Download, verify, extract $WORK/apk.static.
-    """
+    """Download, verify, extract $WORK/apk.static."""
     # Get and parse the APKINDEX. alpine_apkindex_path() will implicitly
     # download the APKINDEX file if it's missing.
     apkindex = pmb.helpers.repo.alpine_apkindex_path("main")
@@ -176,7 +169,10 @@ def init() -> None:
     version = index_data.version
 
     # Verify the apk-tools-static version
-    pmb.helpers.apk.check_outdated(version, "Run 'pmbootstrap update', then try again.")
+    try:
+        pmb.helpers.apk.check_outdated(version)
+    except RuntimeError as exception:
+        raise NonBugError(f"{exception}. Run 'pmbootstrap update', then try again.") from exception
 
     # Download, extract, verify apk-tools-static
     apk_name = f"apk-tools-static-{version}.apk"
