@@ -1,14 +1,13 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
+import os
 import sys
 
 import pmb.config
-from pmb.core.context import Context
+import pmb.helpers.git
+from pmb.core.context import CommandTimeout, Context, TimeoutReason
 from pmb.core.pkgrepo import pkgrepo_default_path
 from pmb.types import PmbArgs
-import pmb.helpers.git
-import pmb.helpers.args
-
 
 """This file constructs the args variable, which is passed to almost all
    functions in the pmbootstrap code base. Here's a listing of the kind of
@@ -64,7 +63,7 @@ def init(args: PmbArgs) -> PmbArgs:
             )
 
     # Override config at runtime with command line arguments
-    for key, _ in vars(config).items():
+    for key in vars(config):
         if key.startswith("_") or key == "user":
             continue
         value = getattr(args, key, None)
@@ -75,14 +74,23 @@ def init(args: PmbArgs) -> PmbArgs:
         if hasattr(args, key):
             delattr(args, key)
 
+    running_in_ci = os.environ.get("CI")
+
     # Configure runtime context
     context = Context(config)
-    context.command_timeout = args.timeout
+    # Only enable the timeout by default in CI.
+    if running_in_ci and args.timeout is None:
+        context.command_timeout = CommandTimeout(length=900, reason=TimeoutReason.CI_DETECTED)
+    elif args.timeout is not None:
+        context.command_timeout = CommandTimeout(
+            length=args.timeout, reason=TimeoutReason.TIMEOUT_ARG
+        )
     context.details_to_stdout = args.details_to_stdout
     context.quiet = args.quiet
     context.offline = args.offline
     context.command = args.action
     context.cross = args.cross
+    context.ccache = args.ccache
     context.assume_yes = getattr(args, "assume_yes", False)
     context.force = getattr(args, "force", False)
 
@@ -93,6 +101,11 @@ def init(args: PmbArgs) -> PmbArgs:
     pmb.helpers.logging.init(context.log, args.verbose, context.details_to_stdout)
     pmb.helpers.logging.debug(f"Pmbootstrap v{pmb.__version__} (Python {sys.version})")
 
+    if context.command_timeout:
+        pmb.helpers.logging.info(
+            f"NOTE: Timeout enabled, commands will be killed after {context.command_timeout.length} seconds of not writing any output. Reason: {context.command_timeout.reason}"
+        )
+
     # Initialization code which may raise errors
     if args.action not in [
         "init",
@@ -108,7 +121,8 @@ def init(args: PmbArgs) -> PmbArgs:
         pmb.helpers.git.parse_channels_cfg(pkgrepo_default_path())
 
     # Remove attributes from args so they don't get used by mistake
-    delattr(args, "timeout")
+    if hasattr(args, "timeout"):
+        delattr(args, "timeout")
     delattr(args, "details_to_stdout")
     delattr(args, "log")
     delattr(args, "quiet")
@@ -120,7 +134,7 @@ def init(args: PmbArgs) -> PmbArgs:
 
     # Copy all properties from args to out that don't start with underscores
     for key, value in vars(args).items():
-        if not key.startswith("_") and not key == "from_argparse":
+        if not key.startswith("_") and key != "from_argparse":
             setattr(args_, key, value)
 
     return args_
