@@ -2,9 +2,10 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 import logging
 import os
-from pathlib import Path
 import sys
+from pathlib import Path
 from typing import Any, Final, TextIO
+
 from pmb.meta import Cache
 
 logfd: TextIO
@@ -96,7 +97,8 @@ class LogHandler(logging.StreamHandler):
 
 
 def add_verbose_log_level() -> None:
-    """Add a new log level "verbose", which is below "debug".
+    """
+    Add a new log level "verbose", which is below "debug".
 
     Also monkeypatch logging, so it can be used with logging.verbose().
 
@@ -105,16 +107,12 @@ def add_verbose_log_level() -> None:
     All stackoverflow user contributions are licensed as CC-BY-SA:
     https://creativecommons.org/licenses/by-sa/3.0/
     """
-    setattr(logging, "VERBOSE", VERBOSE)
+    logging.VERBOSE = VERBOSE  # type: ignore[attr-defined]
     logging.addLevelName(VERBOSE, "VERBOSE")
-    setattr(
-        logging.Logger,
-        "verbose",
-        lambda inst, msg, *args, **kwargs: inst.log(VERBOSE, msg, *args, **kwargs),
-    )
-    setattr(
-        logging, "verbose", lambda msg, *args, **kwargs: logging.log(VERBOSE, msg, *args, **kwargs)
+    logging.Logger.verbose = lambda inst, msg, *args, **kwargs: inst.log(  # type: ignore[attr-defined]
+        VERBOSE, msg, *args, **kwargs
     )
+    logging.verbose = lambda msg, *args, **kwargs: logging.log(VERBOSE, msg, *args, **kwargs)  # type: ignore[attr-defined]
 
 
 def init(logfile: Path, verbose: bool, details_to_stdout: bool = False) -> None:
@@ -129,12 +127,12 @@ def init(logfile: Path, verbose: bool, details_to_stdout: bool = False) -> None:
     # folder and break the folder migration logic, which needs to set the
     # version upon creation)
     if not details_to_stdout and logfile.parent.exists():
-        logfd = open(logfile, "a+")
+        logfd = open(logfile, "a+")  # noqa: SIM115
         logfd.write("\n\n")
     elif details_to_stdout:
         logfd = sys.stdout
     else:
-        logfd = open(os.devnull, "w")
+        logfd = open(os.devnull, "w")  # noqa: SIM115
 
     # Set log format
     root_logger = logging.getLogger()
