@@ -1,18 +1,7 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import fcntl
-from pmb.core.context import get_context
-from pmb.types import (
-    PathString,
-    Env,
-    RunOutputType,
-    RunOutputTypeDefault,
-    RunOutputTypePopen,
-    RunReturnType,
-)
-from pmb.helpers import logging
 import os
-from pathlib import Path
 import selectors
 import shlex
 import subprocess
@@ -20,8 +9,21 @@ import sys
 import threading
 import time
 from collections.abc import Sequence
-from typing import overload, Literal
+from pathlib import Path
+from typing import Literal, overload
+
 import pmb.helpers.run
+from pmb.core.context import get_context
+from pmb.helpers import logging
+from pmb.helpers.exceptions import NonBugError
+from pmb.types import (
+    Env,
+    PathString,
+    RunOutputType,
+    RunOutputTypeDefault,
+    RunOutputTypePopen,
+    RunReturnType,
+)
 
 """For a detailed description of all output modes, read the description of
    core() at the bottom. All other functions in this file get (indirectly)
@@ -31,7 +33,8 @@ import pmb.helpers.run
 def flat_cmd(
     cmds: Sequence[Sequence[PathString]], working_dir: Path | None = None, env: Env = {}
 ) -> str:
-    """Convert a shell command passed as list into a flat shell string with proper escaping.
+    """
+    Convert a shell command passed as list into a flat shell string with proper escaping.
 
     :param cmds: list of commands as list, e.g. ["echo", "string with spaces"]
     :param working_dir: when set, prepend "cd ...;" to execute the command
@@ -61,7 +64,8 @@ def sanity_checks(
     output_return: bool = False,
     check: bool | None = None,
 ) -> None:
-    """Raise an exception if the parameters passed to core() don't make sense.
+    """
+    Raise an exception if the parameters passed to core() don't make sense.
 
     (all parameters are described in core() below).
     """
@@ -139,7 +143,8 @@ def pipe_read(
     output_return: bool = False,
     output_return_buffer: list[bytes] | None = None,
 ) -> None:
-    """Read all output from a subprocess, copy it to the log and optionally stdout and a buffer variable.
+    """
+    Read all output from a subprocess, copy it to the log and optionally stdout and a buffer variable.
 
     This is only meant to be called by foreground_pipe() below.
 
@@ -177,7 +182,8 @@ def pipe_read(
 # FIXME: The docstring claims that ppids should be a list of "process ID tuples", but in practice it
 # gets called with a list of string lists for the ppids argument.
 def kill_process_tree(pid: int | str, ppids: list[list[str]], sudo: bool) -> None:
-    """Recursively kill a pid and its child processes.
+    """
+    Recursively kill a pid and its child processes.
 
     :param pid: process id that will be killed
     :param ppids: list of process id and parent process id tuples (pid, ppid)
@@ -194,7 +200,8 @@ def kill_process_tree(pid: int | str, ppids: list[list[str]], sudo: bool) -> Non
 
 
 def kill_command(pid: int, sudo: bool) -> None:
-    """Kill a command process and recursively kill its child processes.
+    """
+    Kill a command process and recursively kill its child processes.
 
     :param pid: process id that will be killed
     :param sudo: use sudo to kill the process
@@ -222,7 +229,8 @@ def foreground_pipe(
     sudo: bool = False,
     stdin: int | None = None,
 ) -> tuple[int, str]:
-    """Run a subprocess in foreground with redirected output.
+    """
+    Run a subprocess in foreground with redirected output.
 
     Optionally kill it after being silent for too long.
 
@@ -256,25 +264,33 @@ def foreground_pipe(
 
     # While process exists wait for output (with timeout)
     output_buffer: list[bytes] = []
-    sel = selectors.DefaultSelector()
-    sel.register(stdout, selectors.EVENT_READ)
-    timeout = context.command_timeout
+    if context.command_timeout is not None:
+        sel = selectors.DefaultSelector()
+        sel.register(stdout, selectors.EVENT_READ)
     while process.poll() is None:
         wait_start = time.perf_counter()
-        sel.select(timeout)
+        if context.command_timeout is not None:
+            timeout = context.command_timeout.length
 
-        # On timeout raise error (we need to measure time on our own, because
-        # select() may exit early even if there is no data to read and the
-        # timeout was not reached.)
-        if output_timeout:
-            wait_end = time.perf_counter()
-            if wait_end - wait_start >= timeout:
-                logging.info(
-                    "Process did not write any output for " + str(timeout) + " seconds. Killing it."
-                )
-                logging.info("NOTE: The timeout can be increased with 'pmbootstrap -t'.")
-                kill_command(process.pid, sudo)
-                continue
+            try:
+                sel.select(timeout)
+            except OverflowError as exception:
+                raise NonBugError(
+                    f"Specified timeout ({timeout}) isn't valid on this platform, maybe try something smaller ({exception})."
+                ) from exception
+
+            # On timeout raise error (we need to measure time on our own, because
+            # select() may exit early even if there is no data to read and the
+            # timeout was not reached.)
+            if output_timeout:
+                wait_end = time.perf_counter()
+                if wait_end - wait_start >= timeout:
+                    logging.info(
+                        f"Process did not write any output for {timeout} seconds. Killing it. Reason: {context.command_timeout.reason}"
+                    )
+                    logging.info("NOTE: The timeout can be increased with 'pmbootstrap -t'.")
+                    kill_command(process.pid, sudo)
+                    continue
 
         # Read all currently available output
         pipe_read(process, output_to_stdout, output_log, output_return, output_buffer)
@@ -291,7 +307,8 @@ def foreground_pipe(
 def foreground_tui(
     cmd: PathString | Sequence[PathString], working_dir: PathString | None = None
 ) -> int:
-    """Run a subprocess in foreground without redirecting any of its output.
+    """
+    Run a subprocess in foreground without redirecting any of its output.
 
     This is the only way text-based user interfaces (ncurses programs like
     vim, nano or the kernel's menuconfig) work properly.
@@ -302,7 +319,8 @@ def foreground_tui(
 
 
 def check_return_code(code: int, log_message: str) -> None:
-    """Check the return code of a command.
+    """
+    Check the return code of a command.
 
     :param code: exit code to check
     :param log_message: simplified and more readable form of the command, e.g.
@@ -341,7 +359,8 @@ def sudo_timer_start() -> None:
 
 
 def add_proxy_env_vars(env: Env) -> None:
-    """Add proxy environment variables from host to the environment of the command we are running.
+    """
+    Add proxy environment variables from host to the environment of the command we are running.
 
     :param env: dict of environment variables, it will be extended with all of the proxy env vars
         that are set on the host
@@ -371,7 +390,8 @@ def core(
     sudo: bool = False,
     disable_timeout: bool = False,
 ) -> RunReturnType:
-    """Run a command and create a log entry.
+    """
+    Run a command and create a log entry.
 
     This is a low level function not meant to be used directly. Use one of the
     following instead: pmb.helpers.run.user(), pmb.helpers.run.root(),
