@@ -1,15 +1,15 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
-from pathlib import Path
-from pmb.helpers import logging
 import os
 import time
+from pathlib import Path
+
 import pmb.chroot
-import pmb.config
+import pmb.core.dps
 import pmb.install.losetup
 from pmb.core import Chroot
+from pmb.helpers import logging
 from pmb.types import PartitionLayout
-import pmb.core.dps
 
 
 # FIXME (#2324): this function drops disk to a string because it's easier
@@ -49,7 +49,13 @@ def partitions_mount(device: str, layout: PartitionLayout, disk: Path | None) ->
             f"expected it to be at {partition_prefix}1!"
         )
 
-    partitions = [layout["boot"], layout["root"]]
+    partitions = [layout["root"]]
+
+    if layout["prep"]:
+        partitions += [layout["prep"]]
+
+    if layout["boot"]:
+        partitions += [layout["boot"]]
 
     if layout["kernel"]:
         partitions += [layout["kernel"]]
@@ -58,6 +64,8 @@ def partitions_mount(device: str, layout: PartitionLayout, disk: Path | None) ->
         source = Path(f"{partition_prefix}{i}")
         target = Chroot.native() / "dev" / f"installp{i}"
         pmb.helpers.mount.bind_file(source, target)
+        target = Chroot.native() / "dev" / f"{disk.name}p{i}"
+        pmb.helpers.mount.bind_file(source, target)
 
 
 def partition(layout: PartitionLayout, size_boot: int, size_reserve: int) -> None:
@@ -67,9 +75,6 @@ def partition(layout: PartitionLayout, size_boot: int, size_reserve: int) -> Non
     * /dev/installp2: root (or reserved space)
     * /dev/installp3: (root, if reserved space > 0)
 
-    When adjusting this function, make sure to also adjust
-    ondev-prepare-internal-storage.sh in postmarketos-ondev.git!
-
     :param layout: partition layout from get_partition_layout()
     :param size_boot: size of the boot partition in MiB
     :param size_reserve: empty partition between root and boot in MiB (pma#463)
@@ -130,7 +135,6 @@ def partition_cgpt(layout: PartitionLayout, size_boot: int, size_reserve: int) -
     :param size_boot: size of the boot partition in MiB
     :param size_reserve: empty partition between root and boot in MiB (pma#463)
     """
-
     pmb.chroot.apk.install(["cgpt"], Chroot.native(), build=False)
 
     deviceinfo = pmb.parse.deviceinfo()
@@ -227,3 +231,43 @@ def partition_cgpt(layout: PartitionLayout, size_boot: int, size_reserve: int) -
 
     for command in commands:
         pmb.chroot.root(command, check=False)
+
+
+def partition_prep(layout: PartitionLayout) -> None:
+    """
+    Partition /dev/install and create /dev/install{p1,p2}:
+    * /dev/installp1: PReP boot
+    * /dev/installp2: root
+
+    :param layout: partition layout from get_partition_layout()
+    """
+    logging.info("(native) partition /dev/install (PReP boot: 8MB, root: the rest)")
+
+    # Actual partitioning with 'parted'. Using check=False, because parted
+    # sometimes "fails to inform the kernel". In case it really failed with
+    # partitioning, the follow-up mounting/formatting will not work, so it
+    # will stop there (see #463).
+
+    # Only very few OpenFirmware platforms seem to support GPT
+    partition_type = pmb.parse.deviceinfo().partition_type or "msdos"
+
+    commands = [
+        ["mktable", partition_type],
+        ["mkpart", "primary", "1MiB", "9MiB"],
+        ["mkpart", "primary", "9MiB", "100%"],
+        ["set", str(layout["prep"]), "PREP", "on"],
+        ["set", str(layout["prep"]), "boot", "on"],
+    ]
+
+    arch = str(pmb.parse.deviceinfo().arch)
+
+    if partition_type.lower() == "gpt":
+        commands += [
+            ["type", str(layout["prep"]), pmb.core.dps.boot["prep"][1]],
+            ["type", str(layout["root"]), pmb.core.dps.root[arch][1]],
+        ]
+    elif partition_type.lower() == "msdos":
+        commands += [["type", str(layout["prep"]), "0x41"]]  # PReP boot type
+
+    for command in commands:
+        pmb.chroot.root(["parted", "-s", "/dev/install", *command], check=False)
