@@ -1,19 +1,20 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import argparse
+import contextlib
 import os
-from pathlib import Path
 import sys
+from collections.abc import Sequence
+from pathlib import Path
+from typing import Any, cast
 
-from pmb.core.arch import Arch
 from pmb.core import Config
-from pmb.types import PmbArgs
+from pmb.core.arch import Arch
 from pmb.helpers.exceptions import NonBugError
+from pmb.types import PmbArgs, RunOutputTypeDefault
 
-try:
-    import argcomplete  # type:ignore[import-untyped]
-except ImportError:
-    pass
+with contextlib.suppress(ImportError):
+    import argcomplete
 
 import pmb.config
 import pmb.helpers.args
@@ -29,8 +30,11 @@ import pmb.helpers.pmaports
 """
 
 
-def toggle_other_boolean_flags(*other_destinations, value=True):
-    """Group several argparse flags to one.
+def toggle_other_boolean_flags(
+    *other_destinations: str, value: bool = True
+) -> type[argparse.Action]:
+    """
+    Group several argparse flags to one.
 
     Sets multiple other_destination to value.
 
@@ -42,27 +46,34 @@ def toggle_other_boolean_flags(*other_destinations, value=True):
     """
 
     class SetOtherDestinationsAction(argparse.Action):
-        def __init__(self, option_strings, dest, **kwargs):
+        def __init__(self, option_strings: list[str], dest: str, **kwargs: Any) -> None:
             super().__init__(option_strings, dest, nargs=0, const=value, default=value, **kwargs)
 
-        def __call__(self, parser, namespace, values, option_string=None):
+        def __call__(
+            self,
+            parser: argparse.ArgumentParser,
+            namespace: argparse.Namespace,
+            values: str | Sequence[Any] | None,
+            option_string: str | None = None,
+        ) -> None:
             for destination in other_destinations:
                 setattr(namespace, destination, value)
 
     return SetOtherDestinationsAction
 
 
-def type_ondev_cp(val):
-    """Parse and validate arguments to 'pmbootstrap install --ondev --cp'.
+def type_ondev_cp(val: str) -> list[str]:
+    """
+    Parse and validate arguments to 'pmbootstrap install --ondev --cp'.
 
     :param val: 'HOST_SRC:CHROOT_DEST' string
 
-    :returns: (HOST_SRC, CHROOT_DEST)
+    :returns: [HOST_SRC, CHROOT_DEST]
     """
     ret = val.split(":")
 
     if len(ret) != 2:
-        raise argparse.ArgumentTypeError("does not have HOST_SRC:CHROOT_DEST" f" format: {val}")
+        raise argparse.ArgumentTypeError(f"does not have HOST_SRC:CHROOT_DEST format: {val}")
     host_src = ret[0]
     if not os.path.exists(host_src):
         raise argparse.ArgumentTypeError(f"HOST_SRC not found: {host_src}")
@@ -71,11 +82,11 @@ def type_ondev_cp(val):
 
     chroot_dest = ret[1]
     if not chroot_dest.startswith("/"):
-        raise argparse.ArgumentTypeError("CHROOT_DEST must start with '/':" f" {chroot_dest}")
+        raise argparse.ArgumentTypeError(f"CHROOT_DEST must start with '/': {chroot_dest}")
     return ret
 
 
-def arguments_install(subparser):
+def arguments_install(subparser: argparse._SubParsersAction) -> None:
     ret = subparser.add_parser(
         "install", help="set up device specific chroot and install to SD card or image file"
     )
@@ -110,6 +121,14 @@ def arguments_install(subparser):
         choices=[512, 2048, 4096],
     )
 
+    ret.add_argument(
+        "--single-partition",
+        action="store_true",
+        help="Create a single partition that contains both boot and root files."
+        " This can be used on devices that boot without mounting the boot file"
+        " system (e.g. Android boot images or fastboot).",
+    )
+
     # Image type
     group_desc = ret.add_argument_group(
         "optional image type",
@@ -141,8 +160,7 @@ def arguments_install(subparser):
     )
     group.add_argument(
         "--android-recovery-zip",
-        help="generate TWRP flashable zip (recommended read:"
-        " https://postmarketos.org/recoveryzip)",
+        help="generate TWRP flashable zip (recommended read: https://postmarketos.org/recoveryzip)",
         action="store_true",
         dest="android_recovery_zip",
     )
@@ -262,11 +280,11 @@ def arguments_install(subparser):
     # Other
     group = ret.add_argument_group("other optional arguments")
     group.add_argument(
-        "--filesystem", help="root filesystem type", choices=["ext4", "f2fs", "btrfs"]
+        "--filesystem", help="root filesystem type", choices=["ext4", "f2fs", "btrfs", "xfs"]
     )
 
 
-def arguments_export(subparser):
+def arguments_export(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
     ret = subparser.add_parser(
         "export",
         help="create convenience symlinks"
@@ -297,7 +315,7 @@ def arguments_export(subparser):
     return ret
 
 
-def arguments_sideload(subparser):
+def arguments_sideload(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
     ret = subparser.add_parser(
         "sideload", help="Push packages to a running phone connected over usb or wifi"
     )
@@ -325,7 +343,7 @@ def arguments_sideload(subparser):
     return ret
 
 
-def arguments_flasher(subparser):
+def arguments_flasher(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
     ret = subparser.add_parser("flasher", help="flash something to the target device")
     ret.add_argument("--method", help="override flash method", dest="flash_method", default=None)
     sub = ret.add_subparsers(dest="action_flasher")
@@ -346,8 +364,7 @@ def arguments_flasher(subparser):
     flash_kernel.add_argument(
         "--partition",
         default=None,
-        help="partition to flash the kernel to (defaults"
-        " to deviceinfo_flash_*_partition_kernel)",
+        help="partition to flash the kernel to (defaults to deviceinfo_flash_*_partition_kernel)",
     )
 
     # Flash lk2nd
@@ -431,7 +448,7 @@ def arguments_flasher(subparser):
     return ret
 
 
-def arguments_initfs(subparser):
+def arguments_initfs(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
     ret = subparser.add_parser("initfs", help="do something with the initramfs")
     sub = ret.add_subparsers(dest="action_initfs")
 
@@ -457,21 +474,19 @@ def arguments_initfs(subparser):
     return ret
 
 
-def arguments_qemu(subparser):
+def arguments_qemu(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
     ret = subparser.add_parser("qemu")
     ret.add_argument("--cmdline", help="override kernel commandline")
-    ret.add_argument(
-        "--image-size", default="4G", help="set rootfs size, e.g. 2048M or 2G (default: 4G)"
-    )
+    ret.add_argument("--image-size", help="set rootfs size (e.g. 2048M or 2G)")
     ret.add_argument(
         "--second-storage",
         metavar="IMAGE_SIZE",
         help="add a second storage with the given size (default:"
-        " 4G), gets created if it does not exist. Use to"
+        " 8G), gets created if it does not exist. Use to"
         " test install from SD to eMMC",
         nargs="?",
         default=None,
-        const="4G",
+        const="8G",
     )
     ret.add_argument("-m", "--memory", type=int, default=1024, help="guest RAM (default: 1024)")
     ret.add_argument("-p", "--port", type=int, default=2222, help="SSH port (default: 2222)")
@@ -519,9 +534,7 @@ def arguments_qemu(subparser):
         dest="qemu_gl",
         default=True,
         action="store_false",
-        help="Avoid using GL for"
-        " accelerating graphics in QEMU  (use software"
-        " rasterizer, slow!)",
+        help="Avoid using GL for accelerating graphics in QEMU  (use software rasterizer, slow!)",
     )
     ret.add_argument(
         "--video",
@@ -544,12 +557,15 @@ def arguments_qemu(subparser):
     )
 
     ret.add_argument(
-        "--efi", action="store_true", help="Use EFI boot (default: direct kernel image boot)"
+        "--efi",
+        action="store_true",
+        help="Use EFI boot (default: direct kernel image boot if supported by arch)",
     )
+
     return ret
 
 
-def arguments_pkgrel_bump(subparser):
+def arguments_pkgrel_bump(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
     ret = subparser.add_parser(
         "pkgrel_bump",
         help="increase the pkgrel to"
@@ -559,9 +575,7 @@ def arguments_pkgrel_bump(subparser):
     ret.add_argument(
         "--dry",
         action="store_true",
-        help="instead of modifying"
-        " APKBUILDs, exit with >0 when a package would have been"
-        " bumped",
+        help="instead of modifying APKBUILDs, exit with >0 when a package would have been bumped",
     )
 
     # Mutually exclusive: "--auto" or package names
@@ -577,7 +591,7 @@ def arguments_pkgrel_bump(subparser):
     return ret
 
 
-def arguments_pkgver_bump(subparser):
+def arguments_pkgver_bump(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
     ret = subparser.add_parser(
         "pkgver_bump",
         help="increase the pkgver and reset pkgrel to 0. useful when dealing with metapackages.",
@@ -587,7 +601,7 @@ def arguments_pkgver_bump(subparser):
     return ret
 
 
-def arguments_aportupgrade(subparser):
+def arguments_aportupgrade(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
     ret = subparser.add_parser(
         "aportupgrade", help="check for outdated packages that need upgrading"
     )
@@ -609,7 +623,7 @@ def arguments_aportupgrade(subparser):
     return ret
 
 
-def arguments_newapkbuild(subparser):
+def arguments_newapkbuild(subparser: argparse._SubParsersAction) -> None:
     """
     Wrapper for Alpine's "newapkbuild" command.
 
@@ -651,7 +665,7 @@ def arguments_newapkbuild(subparser):
     )
 
 
-def arguments_kconfig(subparser):
+def arguments_kconfig(subparser: argparse._SubParsersAction) -> None:
     # Allowed architectures
     arch_choices = Arch.supported()
 
@@ -683,11 +697,15 @@ def arguments_kconfig(subparser):
         action="store_true",
         help="continue on errors instead of aborting on the first error",
     )
+    check.add_argument(
+        "--categories", help="a comma separated list of additional kconfig categories to check"
+    )
     add_kernel_arg(check, nargs="*")
 
     # "pmbootstrap kconfig edit"
     edit = sub.add_parser("edit", help="edit kernel aport config")
     edit.add_argument("--arch", choices=arch_choices, dest="arch", type=lambda x: Arch.from_str(x))
+    edit.add_argument("--fragment", help="fragment filename to save changes")
     edit_ui_chooser = edit.add_mutually_exclusive_group()
     edit_ui_chooser.add_argument(
         "-x",
@@ -716,52 +734,50 @@ def arguments_kconfig(subparser):
     )
     add_kernel_arg(migrate, nargs=1)
 
+    generate = sub.add_parser("generate", help="generate kernel config from fragments")
+    generate.add_argument(
+        "--arch", choices=arch_choices, dest="arch", type=lambda x: Arch.from_str(x)
+    )
+    add_kernel_arg(generate, nargs=1)
 
-def arguments_repo_bootstrap(subparser):
-    arch_choices = Arch.supported()
 
-    ret = subparser.add_parser("repo_bootstrap")
-    ret.add_argument("repository", help="which repository to bootstrap (e.g. systemd)")
-    ret.add_argument("--arch", choices=arch_choices, dest="arch", type=lambda x: Arch.from_str(x))
-    return ret
-
-
-def arguments_repo_missing(subparser):
-    ret = subparser.add_parser("repo_missing")
-    package = ret.add_argument(
-        "package", nargs="?", help="only look at a specific package and its dependencies"
+def arguments_repo_missing(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
+    ret = subparser.add_parser(
+        "repo_missing",
+        help="list all packages + depends from pmaports for building the repository (used by bpo)",
     )
-    if "argcomplete" in sys.modules:
-        package.completer = package_completer
     ret.add_argument(
         "--arch", choices=Arch.supported(), default=Arch.native(), type=lambda x: Arch.from_str(x)
     )
+    # Deprecated argument that is currently kept so pmbootstrap can be called
+    # the same way for repo_missing by bpo with pmbv2 and pmbv3. Once we drop
+    # support for pmbv2 in bpo (can do that after v24.06 is EOL), we can adjust
+    # bpo to not use --built and remove this parameter from pmbootstrap.
     ret.add_argument(
-        "--built", action="store_true", help="include packages which exist in the binary repos"
-    )
-    ret.add_argument(
-        "--overview", action="store_true", help="only print the pkgnames without any details"
+        "--built",
+        action="store_true",
+        help=argparse.SUPPRESS,
     )
     return ret
 
 
-def arguments_lint(subparser):
+def arguments_lint(subparser: argparse._SubParsersAction) -> None:
     lint = subparser.add_parser("lint", help="run quality checks on pmaports (required to pass CI)")
     add_packages_arg(lint, nargs="*")
 
 
-def arguments_test(subparser):
+def arguments_test(subparser: argparse._SubParsersAction) -> None:
     test = subparser.add_parser("test", help="Internal pmbootstrap test tools")
     sub = test.add_subparsers(dest="action_test", required=True)
     sub.add_parser("apkindex_parse_all", help="parse all APKINDEX files")
 
 
-def arguments_status(subparser):
+def arguments_status(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
     ret = subparser.add_parser("status", help="show a config and pmaports overview")
     return ret
 
 
-def arguments_netboot(subparser):
+def arguments_netboot(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
     ret = subparser.add_parser("netboot", help="launch nbd server with pmOS rootfs")
     sub = ret.add_subparsers(dest="action_netboot")
     sub.required = True
@@ -772,7 +788,7 @@ def arguments_netboot(subparser):
     return ret
 
 
-def arguments_ci(subparser):
+def arguments_ci(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
     ret = subparser.add_parser(
         "ci",
         help="run continuous integration scripts locally of git repo in current directory",
@@ -789,19 +805,29 @@ def arguments_ci(subparser):
     return ret
 
 
-def package_completer(prefix, action, parser=None, parsed_args=None):
-    packages = set(
+def package_completer(
+    prefix: str,
+    action: str,
+    parser: argparse.ArgumentParser | None = None,
+    parsed_args: list[str] | None = None,
+) -> set[str]:
+    packages = {
         package for package in pmb.helpers.pmaports.get_list() if package.startswith(prefix)
-    )
+    }
     return packages
 
 
-def kernel_completer(prefix, action, parser=None, parsed_args=None):
+def kernel_completer(
+    prefix: str,
+    action: str,
+    parser: argparse.ArgumentParser | None = None,
+    parsed_args: list[str] | None = None,
+) -> list[str]:
     """:returns: matched linux-* packages, with linux-* prefix and without"""
-    ret = []
+    ret: list[str] = []
 
     # Full package name, starting with "linux-"
-    if len("linux-") < len(prefix) and prefix.startswith("linux-") or "linux-".startswith(prefix):
+    if (len("linux-") < len(prefix) and prefix.startswith("linux-")) or "linux-".startswith(prefix):
         ret += package_completer(prefix, action, parser, parsed_args)
 
     # Kernel name without "linux-"
@@ -811,21 +837,25 @@ def kernel_completer(prefix, action, parser=None, parsed_args=None):
     return ret
 
 
-def add_packages_arg(subparser, name="packages", *args, **kwargs):
+def add_packages_arg(
+    subparser: argparse.ArgumentParser, name: str = "packages", *args: str, **kwargs: Any
+) -> None:
     arg = subparser.add_argument(name, *args, **kwargs)
     if "argcomplete" in sys.modules:
-        arg.completer = package_completer
+        arg.completer = package_completer  # type: ignore[attr-defined]
 
 
-def add_kernel_arg(subparser, name="package", nargs="?", *args, **kwargs):
+def add_kernel_arg(
+    subparser: argparse.ArgumentParser, name: str = "package", nargs: int | str = "?"
+) -> None:
     arg = subparser.add_argument(
         name, nargs=nargs, help="kernel package (e.g. linux-postmarketos-allwinner)"
     )
     if "argcomplete" in sys.modules:
-        arg.completer = kernel_completer
+        arg.completer = kernel_completer  # type: ignore[attr-defined]
 
 
-def get_parser():
+def get_parser() -> argparse.ArgumentParser:
     parser = argparse.ArgumentParser(prog="pmbootstrap")
     arch_native = Arch.native()
     arch_choices = Arch.supported()
@@ -877,10 +907,8 @@ def get_parser():
     parser.add_argument(
         "-t",
         "--timeout",
-        help="seconds after which processes"
-        " get killed that stopped writing any output (default:"
-        " 900)",
-        default=900,
+        help="seconds after which processes get killed that stopped writing any output (default: "
+        "no timeout unless the environment variable 'CI' is set, in which case it is 900)",
         type=float,
     )
     parser.add_argument(
@@ -945,7 +973,6 @@ def get_parser():
 
     # Actions
     sub = parser.add_subparsers(title="action", dest="action")
-    sub.add_parser("init", help="initialize config file")
     sub.add_parser("shutdown", help="umount, unregister binfmt")
     sub.add_parser(
         "index",
@@ -958,7 +985,6 @@ def get_parser():
         " non-interactively to migrate the"
         " work folder version on demand",
     )
-    arguments_repo_bootstrap(sub)
     arguments_repo_missing(sub)
     arguments_kconfig(sub)
     arguments_export(sub)
@@ -976,6 +1002,14 @@ def get_parser():
     arguments_status(sub)
     arguments_ci(sub)
 
+    # Action: init
+    init = sub.add_parser("init", help="initialize config file")
+    init.add_argument(
+        "--shallow-initial-clone",
+        help="do a shallow clone if pmaports has to be cloned. Primarily useful to speed up scripts.",
+        action="store_true",
+    )
+
     # Action: log
     log = sub.add_parser("log", help="follow the pmbootstrap logfile")
     log.add_argument("-n", "--lines", type=int, default=60, help="count of initial output lines")
@@ -1033,7 +1067,7 @@ def get_parser():
         "-a",
         "--all",
         action=toggle_other_boolean_flags(*zap_all_delete_args),
-        help="delete everything, equivalent to: " f"--{' --'.join(zap_all_delete_args_print)}",
+        help=f"delete everything, equivalent to: --{' --'.join(zap_all_delete_args_print)}",
     )
 
     # Action: stats
@@ -1071,18 +1105,25 @@ def get_parser():
     chroot.add_argument("--user", help="run the command as user, not as root", action="store_true")
     chroot.add_argument(
         "--output",
-        choices=["log", "stdout", "interactive", "tui", "background"],
+        choices=list(RunOutputTypeDefault),
+        type=RunOutputTypeDefault.from_string,
         help="how the output of the"
         " program should be handled, choose from: 'log',"
         " 'stdout', 'interactive', 'tui' (default),"
         " 'background'. Details: pmb/helpers/run_core.py",
-        default="tui",
+        default=RunOutputTypeDefault.TUI,
     )
     chroot.add_argument(
         "--image",
         help="Mount the rootfs image and treat it like a normal chroot.",
         action="store_true",
     )
+    chroot.add_argument(
+        "--usb",
+        help="Make USB devices accessible inside the chroot.",
+        action="store_true",
+        dest="chroot_usb",
+    )
     chroot.add_argument(
         "command",
         default=["sh", "-i"],
@@ -1138,7 +1179,13 @@ def get_parser():
         " sources and verify that the checksums of the"
         " APKBUILD match, instead of updating them",
     )
-    add_packages_arg(checksum, nargs="+")
+    checksum_changed = checksum.add_mutually_exclusive_group(required=True)
+    checksum_changed.add_argument(
+        "--changed",
+        action="store_true",
+        help="update checksums of all packages that have unstaged or uncommitted changes",
+    )
+    checksum_changed.add_argument("packages", nargs="*", default=[])
 
     # Action: aportgen
     aportgen = sub.add_parser(
@@ -1294,8 +1341,9 @@ def get_parser():
     return parser
 
 
-def arguments():
-    args: PmbArgs = get_parser().parse_args()
+def arguments() -> PmbArgs:
+    # FIXME: It would be nice to not use cast here, but I don't know what else we could do.
+    args = cast(PmbArgs, get_parser().parse_args())
 
     if getattr(args, "fork_alpine_retain_branch", False):
         # fork_alpine_retain_branch largely matches the behaviour of fork_alpine, so
@@ -1311,7 +1359,7 @@ def arguments():
         )
 
     if getattr(args, "go_mod_cache", None) is None:
-        gomodcache = True if getattr(args, "src", None) else False
-        setattr(args, "go_mod_cache", gomodcache)
+        gomodcache = bool(getattr(args, "src", None))
+        args.go_mod_cache = gomodcache
 
     return args
