@@ -1,16 +1,15 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import os
-from typing import TextIO
+from pathlib import Path
+from typing import Literal, TextIO
 
+import pmb.chroot
+import pmb.chroot.apk
+import pmb.helpers.run
+from pmb.core import Chroot
 from pmb.core.context import get_context
 from pmb.helpers import logging
-from pathlib import Path
-import pmb.helpers.run
-import pmb.chroot
-import pmb.chroot.other
-import pmb.chroot.apk
-from pmb.core import Chroot
 from pmb.types import Bootimg, PathString
 
 
@@ -23,11 +22,15 @@ def is_dtb(path: PathString) -> bool:
 
 
 def get_mtk_label(path: PathString) -> str | None:
-    """Read the label from the MediaTek header of the kernel or ramdisk inside
+    """
+    Read the label from the MediaTek header of the kernel or ramdisk inside
     an extracted boot.img.
+
     :param path: to either the kernel or ramdisk extracted from boot.img
     :returns: * None: file does not exist or does not have MediaTek header
-    * Label string (e.g. "ROOTFS", "KERNEL")"""
+
+    * Label string (e.g. "ROOTFS", "KERNEL")
+    """
     if not os.path.exists(path):
         return None
 
@@ -54,11 +57,12 @@ def get_mtk_label(path: PathString) -> str | None:
             return label
 
 
-def get_qcdt_type(path: PathString) -> str | None:
-    """Get the dt.img type by reading the first four bytes of the file.
+def get_qcdt_type(path: PathString) -> Literal["qcom", "sprd", "exynos"] | None:
+    """
+    Get the dt.img type by reading the first four bytes of the file.
+
     :param path: to the qcdt image extracted from boot.img
     :returns: * None: dt.img is of unknown type
-    * Type string (e.g. "qcom", "sprd", "exynos")
     """
     if not os.path.exists(path):
         return None
@@ -77,12 +81,13 @@ def get_qcdt_type(path: PathString) -> str | None:
                 return None
 
 
-def get_qcdt_exynos_platform_subtype(path: PathString) -> tuple:
-    """Get the exynos dt.img platform and subtype by reading the first
+def get_qcdt_exynos_platform_subtype(path: PathString) -> tuple[str, str] | tuple[None, None]:
+    """
+    Get the exynos dt.img platform and subtype by reading the first
     four bytes of the file.
+
     :param path: to the qcdt image extracted from boot.img
     :returns: ( Type tuple with platform and subtype, like ("0x50a6", "0x217584da")
-
     """
     if not os.path.exists(path):
         return (None, None)
@@ -151,9 +156,9 @@ def bootimg(path: Path) -> Bootimg:
     header_version = 0
     # Get base, offsets, pagesize, cmdline and qcdt info
     # This file does not exist for example for qcdt images
-    if os.path.isfile(f"{bootimg_path}-header_version"):
-        with open(f"{bootimg_path}-header_version") as f:
-            header_version = int(f.read().replace("\n", ""))
+    bootimg_header_version = Path(f"{bootimg_path}-header_version")
+    if bootimg_header_version.exists():
+        header_version = int(bootimg_header_version.read_text().replace("\n", ""))
 
     if header_version >= 3:
         output["pagesize"] = "4096"
@@ -194,10 +199,10 @@ def bootimg(path: Path) -> Bootimg:
         platform, subtype = get_qcdt_exynos_platform_subtype(f"{bootimg_path}-dt")
         # Omit if platform is default value 0x50a6
         if platform and platform != "0x50a6":
-            output.update({"bootimg_qcdt_exynos_platform": f"0x{platform:04x}"})
+            output.update({"bootimg_qcdt_exynos_platform": platform})
         # Omit if subtype is default value 0x217584da
         if subtype and subtype != "0x217584da":
-            output.update({"bootimg_qcdt_exynos_subtype": f"0x{subtype:08x}"})
+            output.update({"bootimg_qcdt_exynos_subtype": subtype})
 
     output["dtb_second"] = "true" if is_dtb(f"{bootimg_path}-second") else ""
 
