@@ -1,32 +1,30 @@
 # Copyright 2023 Pablo Castellano, Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
-import subprocess
-from collections.abc import Sequence
-from pmb.core.arch import Arch
-from pmb.core.config import Config
-from pmb.core.context import get_context
-from pmb.helpers import logging
-from pmb.helpers.exceptions import NonBugError
 import os
-from pathlib import Path
 import re
-import signal
 import shlex
 import shutil
+import signal
+import subprocess
+from collections.abc import Sequence
+from pathlib import Path
 from types import FrameType
 
 import pmb.build
 import pmb.chroot
 import pmb.chroot.apk
 import pmb.chroot.other
-import pmb.chroot.initfs
-import pmb.config
 import pmb.config.pmaports
-import pmb.install.losetup
-from pmb.types import Env, PathString, PmbArgs, RunOutputTypeDefault
 import pmb.helpers.run
+import pmb.install.losetup
 import pmb.parse.cpuinfo
 from pmb.core import Chroot, ChrootType
+from pmb.core.arch import Arch
+from pmb.core.config import Config
+from pmb.core.context import get_context
+from pmb.helpers import logging
+from pmb.helpers.exceptions import NonBugError
+from pmb.types import Env, PathString, PmbArgs, RunOutputTypeDefault
 
 
 def system_image(device: str) -> Path:
@@ -58,10 +56,8 @@ def create_second_storage(args: PmbArgs, device: str) -> Path:
 
 
 def which_qemu(arch: Arch) -> str:
-    """
-    Finds the qemu executable or raises an exception otherwise
-    """
-    executable = "qemu-system-" + arch.qemu()
+    """Finds the qemu executable or raises an exception otherwise"""
+    executable = "qemu-system-" + arch.qemu_system()
     if shutil.which(executable):
         return executable
     else:
@@ -106,9 +102,7 @@ def command_qemu(
     img_path: Path,
     img_path_2nd: Path | None = None,
 ) -> tuple[list[str | Path], Env]:
-    """
-    Generate the full qemu command with arguments to run postmarketOS
-    """
+    """Generate the full qemu command with arguments to run postmarketOS"""
     device = config.device
     cmdline = pmb.parse.deviceinfo().kernel_cmdline or ""
     if args.cmdline:
@@ -131,16 +125,16 @@ def command_qemu(
     if pmaports_cfg.get("supported_mkinitfs_without_flavors", False):
         flavor_suffix = ""
 
+    # We do not support direct kernel boot on some architectures
+    use_direct_kernel_boot = arch.uses_direct_kernel_image_boot_by_default() and not args.efi
+
     # Alpine kernels always have the flavor appended to /boot/vmlinuz
     kernel = chroot / "boot" / f"vmlinuz{flavor_suffix}"
-    if not kernel.exists():
+    if use_direct_kernel_boot and not kernel.exists():
         kernel = kernel.with_name(f"{kernel.name}-{flavor}")
         if not os.path.exists(kernel):
             raise RuntimeError("failed to find the proper vmlinuz path")
 
-    # Some architectures require using EFI and cannot use direct kernel boot
-    use_efi = args.efi or arch.requires_efi()
-
     ncpus = os.cpu_count()
     if not ncpus:
         logging.warning("Couldn't get cpu count, defaulting to 4")
@@ -210,14 +204,14 @@ def command_qemu(
                 ]
             )
         ]
-        command += [chroot_native / "usr/bin" / f"qemu-system-{arch.qemu()}"]
+        command += [chroot_native / "usr/bin" / f"qemu-system-{arch.qemu_system()}"]
         command += ["-L", chroot_native / "usr/share/qemu/"]
 
     command += ["-nodefaults"]
-    # Only boot a kernel/initramfs directly when not doing EFI boot. This
-    # allows us to load/execute an EFI application on boot, and support
+    # Only boot a kernel/initramfs directly when not doing EFI or OF boot.
+    # This allows us to load/execute an EFI application on boot, and support
     # a wide variety of boot loaders.
-    if not use_efi:
+    if use_direct_kernel_boot:
         command += ["-kernel", kernel]
         command += ["-initrd", chroot / "boot" / f"initramfs{flavor_suffix}"]
         command += ["-append", shlex.quote(cmdline)]
@@ -245,11 +239,21 @@ def command_qemu(
     command += ["-device", "virtio-net-pci,netdev=net"]
 
     # Check that arch is supported by pmb qemu
-    if arch not in [Arch.x86_64, Arch.aarch64, Arch.riscv64, Arch.ppc64le, Arch.loongarch64]:
+    if arch not in [
+        Arch.x86_64,
+        Arch.aarch64,
+        Arch.riscv64,
+        Arch.ppc64le,
+        Arch.loongarch64,
+        Arch.armv7,
+    ]:
         raise RuntimeError(f"Architecture {arch} not supported by this command yet.")
 
     # Apply arch-specific qemu config
     match arch:
+        case Arch.armv7:
+            command += ["-M", "virt"]
+            command += ["-cpu", "cortex-a15"]
         case Arch.aarch64:
             command += ["-M", "virt"]
             command += ["-cpu", "cortex-a57"]
@@ -273,7 +277,7 @@ def command_qemu(
                 # default to 2D-only backend
                 command += ["-device", "virtio-gpu"]
 
-    if use_efi:
+    if not use_direct_kernel_boot:
         host_arch = Arch.native()
         edk2_chroot = chroot_native.path if arch == host_arch else chroot_target.path
         match arch:
@@ -292,6 +296,14 @@ def command_qemu(
                     "-drive",
                     f"if=pflash,format=raw,readonly=on,file={edk2_chroot}/usr/share/edk2/loongarch64/QEMU_EFI.fd",
                 ]
+            case Arch.ppc64le:
+                # ppc64le uses SLOF included in QEMU
+                pass
+            case Arch.riscv64:
+                command += [
+                    "-drive",
+                    f"if=pflash,format=raw,readonly=on,file={edk2_chroot}/usr/share/edk2/riscv/RISCV_VIRT_CODE.fd",
+                ]
             case _:
                 raise RuntimeError(f"Architecture {arch} not configured for EFI support.")
 
@@ -361,16 +373,14 @@ def resize_image(img_size_new: str, img_path: Path) -> None:
         raise RuntimeError(f"IMAGE_SIZE must be {img_size_str} or greater")
 
 
-def sigterm_handler(number: int, stack_frame: FrameType | None) -> None:
+def _sigterm_handler(number: int, stack_frame: FrameType | None) -> None:
     raise RuntimeError(
         "pmbootstrap was terminated by another process, and killed the QEMU VM it was running."
     )
 
 
 def install_depends(args: PmbArgs, arch: Arch) -> None:
-    """
-    Install any necessary qemu dependencies in native chroot
-    """
+    """Install any necessary qemu dependencies in native chroot"""
     depends = [
         "mesa-dri-gallium",
         "mesa-egl",
@@ -385,7 +395,7 @@ def install_depends(args: PmbArgs, arch: Arch) -> None:
         "qemu-hw-display-virtio-gpu-pci-gl",
         "qemu-hw-display-virtio-vga",
         "qemu-hw-display-virtio-vga-gl",
-        "qemu-system-" + arch.qemu(),
+        "qemu-system-" + arch.qemu_system(),
         "qemu-ui-gtk",
         "qemu-ui-opengl",
         "qemu-ui-sdl",
@@ -399,7 +409,11 @@ def install_depends(args: PmbArgs, arch: Arch) -> None:
         depends.remove("qemu-hw-display-virtio-vga")
         depends.remove("qemu-ui-opengl")
 
-    if args.efi or arch.requires_efi():
+    use_direct_kernel_boot = arch.uses_direct_kernel_image_boot_by_default() and not args.efi
+
+    if not use_direct_kernel_boot:
+        edk2_pkg = None
+
         # EDK2 builds are only available for the target architecture
         match arch:
             case Arch.aarch64:
@@ -408,14 +422,19 @@ def install_depends(args: PmbArgs, arch: Arch) -> None:
                 edk2_pkg = "ovmf"
             case Arch.loongarch64:
                 edk2_pkg = "edk2-loongarch64"
+            case Arch.ppc64le:
+                # ppc64le uses SLOF included in QEMU instead of EFI
+                pass
+            case Arch.riscv64:
+                edk2_pkg = "ovmf"
             case _:
                 raise RuntimeError(f"Architecture {arch} not configured for EFI support.")
 
         # If we're running natively, install it to the native chroot, otherwise we need to
         # install it in the target chroot
-        if arch == Arch.native():
+        if edk2_pkg is not None and arch == Arch.native():
             depends.append(edk2_pkg)
-        else:
+        elif edk2_pkg is not None:
             target_chroot = Chroot.buildroot(arch)
             pmb.chroot.init(target_chroot)
             pmb.chroot.apk.install([edk2_pkg], target_chroot)
@@ -426,9 +445,7 @@ def install_depends(args: PmbArgs, arch: Arch) -> None:
 
 
 def run(args: PmbArgs) -> None:
-    """
-    Run a postmarketOS image in qemu
-    """
+    """Run a postmarketOS image in qemu"""
     config = get_context().config
     device = config.device
     if not device.startswith("qemu-"):
@@ -450,7 +467,7 @@ def run(args: PmbArgs) -> None:
 
     if not args.host_qemu:
         install_depends(args, arch)
-    logging.info("Running postmarketOS in QEMU VM (" + arch.qemu() + ")")
+    logging.info("Running postmarketOS in QEMU VM (" + arch.qemu_system() + ")")
 
     qemu, env = command_qemu(args, config, arch, img_path, img_path_2nd)
 
@@ -489,7 +506,7 @@ def run(args: PmbArgs) -> None:
     # Run QEMU and kill it together with pmbootstrap
     process = None
     try:
-        signal.signal(signal.SIGTERM, sigterm_handler)
+        signal.signal(signal.SIGTERM, _sigterm_handler)
         process = pmb.helpers.run.user(qemu, output=RunOutputTypeDefault.TUI, env=env)
     except KeyboardInterrupt:
         # In addition to not showing a trace when pressing ^C, let user know
