@@ -2,10 +2,10 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 import pytest
-
-from pmb.core.pkgrepo import pkgrepo_paths, pkgrepo_default_path
 from _pytest.monkeypatch import MonkeyPatch
 
+from pmb.core.pkgrepo import pkgrepo_default_path, pkgrepo_paths
+
 
 @pytest.mark.parametrize("config_file", ["no-repos"], indirect=True)
 def test_pkgrepo_paths_no_repos(pmb_args: None) -> None:
@@ -18,7 +18,6 @@ def test_pkgrepo_paths_no_repos(pmb_args: None) -> None:
 
 def test_pkgrepo_pmaports(pmaports: None, monkeypatch: MonkeyPatch) -> None:
     """Test pkgrepo_paths() with pmaports repository and systemd extra repo"""
-
     # Disable results caching
     pkgrepo_paths.cache_disable()
     pkgrepo_default_path.cache_disable()
