@@ -2,16 +2,16 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 from pathlib import Path
-from pmb.core.arch import Arch
+
 import pytest
 from _pytest.monkeypatch import MonkeyPatch
 
 import pmb.parse.apkindex
-
+from pmb.core.arch import Arch
 from pmb.parse.apkindex import (
-    parse as parse_apkindex,
     clear_cache as clear_apkindex_cache,
     package as package_apkindex,
+    parse as parse_apkindex,
 )
 
 example_apkindex = """
@@ -247,8 +247,7 @@ def valid_apkindex_file(tmp_path: Path) -> Path:
     # FIXME: use tmpfile fixture from !2453
     tmpfile = tmp_path / "APKINDEX.1"
     print(tmp_path)
-    with open(tmpfile, "w") as f:
-        f.write(example_apkindex)
+    tmpfile.write_text(example_apkindex)
 
     return tmpfile
 
@@ -322,11 +321,9 @@ def test_apkindex_parse(valid_apkindex_file: Path) -> None:
 
 def test_apkindex_parse_bad_priority(tmp_path: Path) -> None:
     tmpfile = tmp_path / "APKINDEX.2"
-    with open(tmpfile, "w") as f:
-        # A snippet of the above example but with the provider_priority
-        # of postmarketos-initramfs set to a non-integer value
-        f.write(
-            """
+    # A snippet of the above example but with the provider_priority
+    # of postmarketos-initramfs set to a non-integer value
+    tmpfile.write_text("""
 C:Q1yB3CVUFMOjnLOOEAUIUUpJJV8g0=
 P:postmarketos-base-ui-x11
 V:29-r1
@@ -359,8 +356,7 @@ t:1728049308
 c:f3a4285732781d5577bad06046b7bbeaf132ce1f-dirty
 k:beep
 D:blkid btrfs-progs buffyboard busybox-extras bzip2 cryptsetup device-mapper devicepkg-utils>=0.2.0 dosfstools e2fsprogs e2fsprogs-extra f2fs-tools font-terminus iskey kmod libinput-libs lz4 multipath-tools parted postmarketos-fde-unlocker postmarketos-mkinitfs>=2.2 udev unudhcpd util-linux-misc xz
-p:postmarketos-ramdisk=3.3.5-r2"""
-        )
+p:postmarketos-ramdisk=3.3.5-r2""")
 
     # We expect a RuntimeError to be raised when provider_priority is not
     # an integer
@@ -370,11 +366,9 @@ p:postmarketos-ramdisk=3.3.5-r2"""
 
 def test_apkindex_parse_missing_optionals(tmp_path: Path) -> None:
     tmpfile = tmp_path / "APKINDEX.3"
-    with open(tmpfile, "w") as f:
-        # A snippet of the above example but with a missing timestamp
-        # and origin fields
-        f.write(
-            """
+    # A snippet of the above example but with a missing timestamp
+    # and origin fields
+    tmpfile.write_text("""
 C:Q1yB3CVUFMOjnLOOEAUIUUpJJV8g0=
 P:postmarketos-base-ui-x11
 V:29-r1
@@ -388,8 +382,7 @@ m:Clayton Craft <clayton@craftyguy.net>
 c:901cb9520450a1e88ded95ac774e83f6b2cfbba3-dirty
 D:libinput xf86-input-libinput xf86-video-fbdev
 p:postmarketos-base-x11=29-r1
-i:postmarketos-base-ui=29-r1 xorg-server"""
-        )
+i:postmarketos-base-ui=29-r1 xorg-server""")
 
     # We expect parsing to succeed when the timestamp is missing
     parse_apkindex(tmpfile, True)
@@ -397,11 +390,9 @@ i:postmarketos-base-ui=29-r1 xorg-server"""
 
 def test_apkindex_parse_trailing_newline(tmp_path: Path) -> None:
     tmpfile = tmp_path / "APKINDEX.4"
-    with open(tmpfile, "w") as f:
-        # A snippet of the above example but with additional
-        # trailing newlines
-        f.write(
-            """
+    # A snippet of the above example but with additional
+    # trailing newlines
+    tmpfile.write_text("""
 C:Q1yB3CVUFMOjnLOOEAUIUUpJJV8g0=
 P:postmarketos-base-ui-x11
 V:29-r1
@@ -418,8 +409,7 @@ p:postmarketos-base-x11=29-r1
 i:postmarketos-base-ui=29-r1 xorg-server
 
 
-"""
-        )
+""")
 
     # We expect parsing to succeed when the timestamp is missing
     parse_apkindex(tmpfile, True)
@@ -462,11 +452,9 @@ def test_apkindex_package(valid_apkindex_file: Path) -> None:
 
 def test_apkindex_package_provider_priority(tmp_path: Path) -> None:
     tmpfile = tmp_path / "APKINDEX.5"
-    with open(tmpfile, "w") as f:
-        # A snippet of the above example but with a missing timestamp
-        # and origin fields
-        f.write(
-            """
+    # A snippet of the above example but with a missing timestamp
+    # and origin fields
+    tmpfile.write_text("""
 C:Q1yB3CVUFMOjnLOOEAUIUUpJJV8g0=
 P:postmarketos-base-short
 V:20-r0
@@ -500,8 +488,7 @@ c:901cb9520450a1e88ded95ac774e83f6b2cfbba3-dirty
 D:kbd kmod less login-utils systemd systemd-services systemd-timesyncd tzdata
 p:postmarketos-base-init
 k:100
-"""
-        )
+""")
 
     index_block = package_apkindex("postmarketos-base-init", arch=Arch.aarch64, indexes=[tmpfile])
     assert index_block is not None
@@ -512,11 +499,9 @@ k:100
 
 def test_apkindex_package_provider_shortest(tmp_path: Path) -> None:
     tmpfile = tmp_path / "APKINDEX.6"
-    with open(tmpfile, "w") as f:
-        # A snippet of the above example but with a missing timestamp
-        # and origin fields
-        f.write(
-            """
+    # A snippet of the above example but with a missing timestamp
+    # and origin fields
+    tmpfile.write_text("""
 C:Q1yB3CVUFMOjnLOOEAUIUUpJJV8g0=
 P:mesa-egl
 V:20-r0
@@ -546,8 +531,7 @@ m:Clayton Craft <clayton@craftyguy.net>
 t:1729538699
 c:901cb9520450a1e88ded95ac774e83f6b2cfbba3-dirty
 p:so:libGL.so.1=22-r0
-"""
-        )
+""")
 
     index_block = package_apkindex("so:libGL.so.1", arch=Arch.aarch64, indexes=[tmpfile])
     assert index_block
